@@ -34,7 +34,7 @@
 #include <libxml/tree.h>
 #include <folks/folks.h>
 #include <folks/folks-telepathy.h>
-#include <telepathy-glib/account-manager.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "empathy-contact.h"
 
